#include "mainwindow.h"
#include "ui_mainwindow.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::on_action_Quit_triggered()
{
    close();
}

#include <QDir>

void MainWindow::on_action_Run_triggered()
{
    // QDir dir ("/usr/share/icons/oxygen/base");
    QDir dir ("..");
    QTreeWidgetItem * item = new QTreeWidgetItem;
    QString path = dir.absolutePath();
    item->setText (0, path);
    item->setToolTip (0, path);
    item->setData (0, Qt::UserRole, path);
    item->setForeground (0, QColor ("red"));
    item->setIcon (0, QIcon::fromTheme ("folder"));
    ui->treeWidget->invisibleRootItem()->addChild (item);
    showDir(item, dir);
}

void MainWindow::showDir (QTreeWidgetItem *target, QDir dir)
{
    QFileInfoList list = dir.entryInfoList
             (QDir::NoDotAndDotDot | QDir::AllEntries , QDir::Name);
    for (QFileInfo info : list)
    {
        QTreeWidgetItem * item = new QTreeWidgetItem;
        item->setText (0, info.fileName());
        QString path = info.absoluteFilePath();
        item->setToolTip (0, path);
        item->setData (0, Qt::UserRole, path);
        target->addChild(item);
        if (info.isDir())
        {
            item->setForeground (0, QColor ("red"));
            item->setIcon (0, QIcon::fromTheme ("folder"));
            showDir (item, QDir (path));
        }
        else
        {
            item->setForeground (0, QColor ("blue"));
            QString ext = info.suffix();
            QString fname = path;
            if (ext == "cpp")
                item->setForeground (0, QColor ("lime"));
            else if (ext == "png")
            {
                item->setForeground (0, QColor ("orange"));
                QIcon icon = QIcon (fname);
                item->setIcon (0, icon);
            }
        }
    }
}

void MainWindow::on_treeWidget_itemClicked(QTreeWidgetItem *item, int column)
{
    QString path = item->data (0, Qt::UserRole).toString();
    // ui->textEdit->append ("Click " + path);
    QFileInfo fi (path);
    QString ext = fi.suffix();
    if (ext == "h" || ext == "cpp")
        readText (path);
    else if (ext == "dat")
        readData (path);
}

void MainWindow::readData (QString path)
{
    ui->tabWidget->setCurrentIndex(1);
    ui->tableWidget->setColumnCount(10);
    ui->tableWidget->setRowCount(10);

    QFile f (path);
    if (f.open (QFile::ReadOnly | QFile::Text))
    {
        int line = 0;
        while (! f.atEnd())
        {
            QString s = f.readLine ();
            QStringList list = s.split(';');
            int col = 0;
            for (QString t : list)
            {
                t = t.simplified ();
                QTableWidgetItem * item = new QTreeWidgetItem;
                item->setText (t);
                ui->tableWidget->setItem (line, col, item);
                col ++;
            }
            line ++;
        }
        f.close ();
    }
}

void MainWindow::readText (QString path)
{
    ui->tabWidget->setCurrentIndex(0);
    ui->textEdit->clear ();

    QFile f (path);
    if (f.open (QFile::ReadOnly | QFile::Text))
    {
        QByteArray b = f.readAll();
        ui->textEdit->setText (b);
        f.close ();
    }
}

